#
# spec file for package python-oslo.serialization
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-oslo.serialization
Version:        5.4.0
Release:        1.1
Summary:        OpenStack serialization library
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://docs.openstack.org/oslo.serialization
Source0:        https://files.pythonhosted.org/packages/source/o/oslo.serialization/oslo.serialization-5.4.0.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python3-msgpack >= 0.5.2
BuildRequires:  python3-netaddr
BuildRequires:  python3-oslo.i18n
BuildRequires:  python3-oslo.utils >= 3.33.0
BuildRequires:  python3-oslotest
BuildRequires:  python3-pbr >= 2.0.0
BuildRequires:  python3-stestr
BuildArch:      noarch

%description
The oslo.serialization library provides support for representing objects
in transmittable and storable formats, such as Base64, JSON and MessagePack.

%package -n python3-oslo.serialization
Summary:        OpenStack serialization library
Requires:       python3-msgpack >= 0.5.2
Requires:       python3-oslo.utils >= 3.33.0
Requires:       python3-pytz >= 2013.6

%description -n python3-oslo.serialization
The oslo.serialization library provides support for representing objects
in transmittable and storable formats, such as Base64, JSON and MessagePack.

This package contains the Python 3.x module.

%package -n python-oslo.serialization-doc
Summary:        Documentation for OpenStack serialization library
BuildRequires:  python3-Sphinx
BuildRequires:  python3-openstackdocstheme

%description -n python-oslo.serialization-doc
The oslo.serialization library provides support for representing objects
in transmittable and storable formats, such as Base64, JSON and MessagePack.
This package contains the documentation.

%prep
%autosetup -p1 -n oslo.serialization-5.4.0
sed -i -e "s,bandit.*,," test-requirements.txt
%py_req_cleanup

%build
%{py3_build}

# generate html docs
PBR_VERSION=%{version} %sphinx_build -b html doc/source doc/build/html
# remove the sphinx-build leftovers
rm -rf doc/build/html/.{doctrees,buildinfo}

%install
%{py3_install}

%check
%{openstack_stestr_run}

%files -n python3-oslo.serialization
%license LICENSE
%doc README.rst ChangeLog
%{python3_sitelib}/oslo_serialization
%{python3_sitelib}/*.egg-info

%files -n python-oslo.serialization-doc
%license LICENSE
%doc doc/build/html

%changelog
* Thu May  2 2024 cloud-devel@suse.de
- update to version 5.4.0
  - Update master for stable/2023.2
  - bandit: Disable B411
  - reno: Update master for unmaintained/yoga
  - pre-commit: Bump versions
  - pre-commit: Integrate bandit
  - Update python classifier in setup.cfg
  - Display coverage report
  - Require pytz only in Python < 3.9
  - Bump bandit
  - jsonutils: Raise ValueError in case the input can't be converted
* Fri Dec  1 2023 cloud-devel@suse.de
- update to version 5.2.0
  - Revert "Moves supported python runtimes from version 3.8 to 3.10"
  - Fix compatibility with Python 3.8
  - Remove extra spaces in tox.ini
  - Use the new openstack-python3-jobs template
  - Update master for stable/2023.1
  - Implement zoneinfo support to drop dependency to pytz
  - Moves supported python runtimes from version 3.8 to 3.10
* Mon Mar  6 2023 cloud-devel@suse.de
- update to version 5.1.1
  - Fix issues related to tox4
  - Update master for stable/zed
  - Add Python3 antelope unit tests
* Sun Oct  2 2022 cloud-devel@suse.de
- update to version 5.0.0
  - Remove unnecessary unicode prefixes
  - Drop python3.6/3.7 support in testing runtime
  - Add Python3 zed unit tests
  - Update master for stable/yoga
* Tue May 24 2022 cloud-devel@suse.de
- update to version 4.3.0
  - setup.cfg: Replace dashes with underscores
  - Update master for stable/xena
  - Add Python3 yoga unit tests
* Tue Oct 26 2021 cloud-devel@suse.de
- update to version 4.2.0
  - Move flake8 as a pre-commit local target.
  - Update master for stable/wallaby
  - Remove lower-constraints remnants
  - setup.cfg: Replace dashes with underscores
  - Use TOX_CONSTRAINTS_FILE
  - Add Python3 xena unit tests
  - Drop use of deprecated collections classes
* Sun May  2 2021 cloud-devel@suse.de
- update to version 4.1.0
  - ignore reno generated artifacts
  - Use py3 as the default runtime for tox
  - Adding pre-commit
  - Update master for stable/victoria
  - Add Python3 wallaby unit tests
  - Dropping lower constraints testing
  - Fix hacking min version to 3.0.1
  - Fix json to_primitive when using IO OBjects
* Fri Oct  9 2020 cloud-devel@suse.de
- update to version 4.0.1
  - Add py38 package metadata
  - Bump default tox env from py37 to py38
  - Bump bandit version
  - Update master for stable/ussuri
  - Remove the unused coding style modules
  - Fix pygments style
  - Align contributing doc with oslo's policy
  - Switch to newer openstackdocstheme and reno versions
  - Remove the yamlutils module.
  - Update openstackdocstheme.
  - Stop to use the __future__ module.
  - Add release notes links to doc index
  - Remove translation sections from setup.cfg
  - Add Python3 victoria unit tests
* Tue May 12 2020 cloud-devel@suse.de
- update to version 3.1.1
  - Switch to Ussuri jobs
  - remove outdated header
  - Remove Python 3-specific conditional in dump_as_bytes
  - [ussuri][goal] Drop python 2.7 support and testing
  - tox: Trivial cleanup
  - Update master for stable/train
  - reword releasenote for py27 support dropping
  - Deprecated the yamlutils module.
  - Drop use of six
  - Remove long-dead workaround
  - Update hacking for Python3
  - Add releasenote to deprecate the yamlutils module
  - tox: Keeping going with docs
  - Update the minversion parameter.
  - Use unittest.mock instead of third party mock
* Sat Mar 14 2020 Dirk Mueller <dmueller@suse.com>
- switch to python 3.x only builds
* Wed Oct  9 2019 cloud-devel@suse.de
- update to version 2.29.2
  - Dropping the py35 testing
  - Introduce a base yaml parser for all openstack components
  - Sync Sphinx requirement
  - Cap sphinx for py2 to match global requirements
  - Explicitly set default_flow_style to False
  - Resolve some issue with tox.ini, setup.cfg
  - OpenDev Migration Patch
  - Add Python 3 Train unit tests
  - Update master for stable/stein
  - Replace git.openstack.org URLs with opendev.org URLs
* Mon Apr  8 2019 cloud-devel@suse.de
- update to version 2.28.2
  - Update mailinglist from dev to discuss
  - Clean up .gitignore references to personal tools
  - Switch to stestr
  - Fix README
  - Update hacking version
  - Update reno for stable/rocky
  - Add release notes link to README
  - Use template for lower-constraints
  - Update the home-page to latest
  - add lib-forward-testing-python3 test job
  - add python 3.6 unit test job
  - py37: deal with Exception repr changes
  - add python 3.7 unit test job
  - import zuul job settings from project-config
* Mon Sep  3 2018 cloud-devel@suse.de
- update to version 2.27.0
  - Remove stale pip-missing-reqs tox test
  - set default python to python3
  - fix tox python3 overrides
  - Update reno for stable/queens
  - Update links in README
  - Trivial: Update pypi url to new url
  - Stop using encoding='utf-8' with msgpack
  - Unblock requirements changes
  - Follow the new PTI for document build
  - Updated from global requirements
  - add lower-constraints job
  - msgpack-python has been renamed to msgpack
* Fri Feb 23 2018 tbechtold@suse.com
- Switch to stable/queens spec template
* Mon Feb 12 2018 cloud-devel@suse.de
- update to version 2.24.0
  - When serializing an exception return its 'repr'
  - Remove -U from pip install
  - Remove setting of version/release from releasenotes
  - Update .gitreview for stable/queens
  - Avoid tox_install.sh for constraints support
  - Add bandit to pep8 job
  - Updated from global requirements
  - msgpack-python has been renamed to msgpack
* Mon Jan 15 2018 cloud-devel@suse.de
- update to version 2.21.1 (bsc#1078607)
  - Update reno for stable/pike
  - warn developers when can't convert value into primitive
  - Updated from global requirements
  - jsonutils.to_primitive(): add fallback parameter
* Mon Aug  7 2017 cloud-devel@suse.de
- update to version 2.20.0
  - rearrange existing documentation to fit the new standard layout
  - Remove references to Python 3.4
  - Revert "Explicitly raise ValueError in to_primitive"
  - Don't iterate through addresses in netaddr.IPNetwork
  - Update URLs in documents according to document migration
  - [Fix gate]Update test requirement
  - switch from oslosphinx to openstackdocstheme
  - Update reno for stable/ocata
  - Explicitly raise ValueError in to_primitive
  - Updated from global requirements
  - Use Sphinx 1.5 warning-is-error
* Mon Feb 13 2017 cloud-devel@suse.de
- update to version 2.16.0:
  - modify the home-page info with the developer documentation
  - Updated from global requirements
  - Add a title to the API Documentation page
  - Add Constraints support
  - Show team and repo badges on README
  - Replace six.iteritems() with .items()
  - Prefer raising the python2.x type error for b64 decode errors
  - Replaces uuid.uuid4 with uuidutils.generate_uuid()
  - Add reno for release notes management
  - Don't raise TypeError for invalid b64
* Fri Oct 14 2016 tbechtold@suse.com
- switch to stable/newton tarball in _service
* Fri Sep  2 2016 tbechtold@suse.com
- update to version 2.13.0
  * Fix serialization of binary strings in Python3
  * Drop H803 in flake8 ignore list
* Wed Aug 10 2016 tbechtold@suse.com
- update to 2.12.0:
  * Updated from global requirements
  * Fix parameters of assertEqual are misplaced
  * Add Python 3.5 classifier and venv
  * Use {} instead of dict()
  * Replace TypeError by ValueError in msgpackutils
  * Support serializing ipaddress objs with jsonutils
* Sun Jun 19 2016 dmueller@suse.com
- update to 2.7.0:
  * Trivial: ignore openstack/common in flake8 exclude list
  * [Trivial] Remove executable privilege of doc/source/conf.py
  * Drop babel as requirement since its not used
  * Updated from global requirements
  * Unified and simplified API for all serializers
  * Make msgpack registries copyable (and add __contains__)
  * msgpack: fix datetime serialization
* Thu Jun  2 2016 tbechtold@suse.com
- use renderspec source service
- update spec from upstream
* Thu Mar  3 2016 tbechtold@suse.com
- update to 2.4.0:
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Remove fallback to simplejson in jsonutils
  * Remove iso8601 dependency
  * Updated from global requirements
  * Updated from global requirements
  * Trival: Remove 'MANIFEST.in'
  * msgpackutils: drop Python 2.6 support
  * Updated from global requirements
  * Updated from global requirements
  * Remove python 2.6 classifier
  * Fix bug track URL
  * Remove python 2.6 and cleanup tox.ini
  * Updated from global requirements
- Switch to .spec from rpm-packaging upstream project
* Fri Nov 20 2015 bwiedemann@suse.com
- update to 1.11.0
  * Fix coverage configuration and execution
- update to 1.10.0:
  * Add utilities for base64
  * Also check for the existence of `items` in to_primitive()
  * Move 'history' -> release notes section
  * Add jsonutils.dump_as_bytes() function for py3
  * Change ignore-errors to ignore_errors
* Wed Sep  9 2015 tbechtold@suse.com
- update to 1.9.0:
  * Updated from global requirements
  * Drop stale test - test_jsonutils
  * Stop using deprecated oslo_utils.timeutils.strtime
  * Add tox target to find missing requirements
  * Remove oslo namespace package
  * Do not use oslo namespace for oslo.i18n lib
  * Switch badges from 'pypip.in' to 'shields.io'
- Adjust Requires according to requirements.txt
* Mon Aug 10 2015 seife+obs@b1-systems.com
- fix spelling of python-Sphinx BuildRequires
* Fri Jul 31 2015 tbechtold@suse.com
- Unify spec file #2
- Add -doc package
* Wed Jul 29 2015 tbechtold@suse.com
- Unify spec file. Use fedora compatible files macros
* Mon Jun  8 2015 tbechtold@suse.com
- update to 1.6.0:
  * Revert "jsonutils: replace strtime(
  * jsonutils: encode dict keys
  * jsonutils: simplify simple value handling
  * jsonutils: replace strtime() usage with isoformat()
  * Advertise support for Python3.4 / Remove support for Python 3.3
  * Do not sync run_cross_tests.sh
  * Updated from global requirements
  * Remove run_cross_tests.sh
  * Fixes wrong folder for listing tests
  * Expose base msgpack exceptions so users don't need to import
  * Uncap library requirements for liberty
  * More docstring cleanups/tweaks
  * Add docstring(s) to handler registry(s)
  * Add pypi download + version badges
  * Cleanup README.rst and setup.cfg
  * Make the msgpackutils handlers more extendable
  * Updated from global requirements
- Adjust Requires according to requirements.txt
* Wed Jun  3 2015 dmueller@suse.com
- remove hacking dep
* Tue Mar 10 2015 tbechtold@suse.com
- update to 1.4.0:
  * Updated from global requirements
- update Requires
* Tue Feb 24 2015 tbechtold@suse.com
- update to version 1.3.0:
  * add dependency warning to requirements.txt
  * Correctly load and dump items with datetime.date(s)
  * Avoid using strtime for serializing datetimes
  * jsonutils: add set() tests and simplify recursive code
  * jsonutils: support UUID encoding
  * Use default in dumps()
  * Updated from global requirements
  * Update Oslo imports to remove namespace package
  * Add a messagepack utils helper module
  * Bump to hacking 0.10
  * Updated from global requirements
  * fix bug tracker link in README.rst
- Add python-pytz and python-msgpack-python as Requires
- Remove SLES11 compat
* Thu Jan 15 2015 tbechtold@suse.com
- update to 1.2.0:
  * Move files out of the namespace package
  * Activate pep8 check that _ is imported
  * Updated from global requirements
  * Workflow documentation is now in infra-manual
- Add python_requires to _service
* Thu Jan  8 2015 dmueller@suse.com
- update to 1.1.0:
  * Add pbr to installation requirements
  * Updated from global requirements
  * Fix pep8, docs, requirements issues in jsonutils and tests
  * Remove extraneous vim editor configuration comments
  * Support building wheels (PEP-427)
  * Fix coverage testing
  * Updated from global requirements
  * Support 'built-in' datetime module
* Fri Oct 17 2014 dmueller@suse.com
- add LICENSE
* Sun Sep 21 2014 tbechtold@suse.com
- Update to version 1.0.0:
  * Updated from global requirements
- Adjust Requires version of python-oslo.utils according to
  requirements.txt
* Tue Sep  9 2014 tbechtold@suse.com
- Initial version
